==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ro/general.php <==
<?php

    return [
    'accessories'			=> 'Accesorii',
    'activated'			    => 'activat',
    'accessory'				=> 'Accesorii',
    'accessory_report'		=> 'Raportul accesoriu',
    'action'                => 'Acțiune',
    'activity_report'		=> 'Raport de activitate',
    'address'				=> 'Adresa',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Adăugat scaune',
    'all_assets'			=> 'Toate activele',
    'all'       			=> 'Toate',
    'archived'              => 'Arhivat',
    'asset_models'			=> 'Modele active',
    'asset_model'			=> 'Model',
    'asset'					=> 'Activ',
    'asset_report'          => 'Raport de active',
    'asset_tag'				=> 'Eticheta activ',
    'assets_available'		=> 'Active disponibile',
    'audit'				    => 'Audit',
    'audit_report'			=> 'Jurnal de audit',
    'assets'				=> 'Active',
    'avatar_delete'         => 'Sterge avatar',
    'avatar_upload'         => 'Upload Avatar',
    'back'      			=> 'Inapoi',
    'bad_data'      		=> 'Nimic gasit. Poate date proaste?',
    'bulkaudit'             => 'Auditul în bloc',
    'bulkaudit_status'      => 'Starea auditului',
    'bulk_checkout'  		=> 'Comenzi în numerar',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Anuleaza',
    'categories'			=> 'Categorii',
    'category'				=> 'Categoria',
    'change' 		        => 'În afară',
    'changeemail'  			=> 'Schimba adresa de E-mail',
    'changepassword'  		=> 'Schimba parola',
    'checkin'  				=> 'Primeste',
    'checkin_from'  		=> 'Checkin de la',
    'checkout'  			=> 'Preda',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Requests',
    'city'  				=> 'Oras',
	'click_here'			=> 'Click aici',
    'clear_selection'		=> 'Clear Selection',
    'companies'			    => 'Companii',
    'company'				=> 'Companie',
    'component'			    => 'component',
    'components'			=> 'Componente',
	'complete'				=> 'Complet',
    'consumable'			=> 'Consumabil',
    'consumables'			=> 'Consumabile',
    'country'  				=> 'Tara',
    'create'				=> 'Creeaza',
    'created'               => 'Articol creat',
    'created_asset'			=> 'Activ creat',
    'created_at' 			=> 'Creat la',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Actualizat la',
    'currency'  			=> 'LEI', // this is deprecated
    'current'  				=> 'Curent',
    'custom_report'         => 'Raport active custom',
    'dashboard'				=> 'Bord',
    'days'      			=> 'zi',
    'days_to_next_audit'    => 'Zile până la următorul audit',
    'date'					=> 'Data',
    'debug_warning'         => 'Avertizare!',
    'debug_warning_text'    => 'Această aplicație rulează în modul de producție cu debugging activat. Acest lucru poate expune date sensibile dacă aplicația dvs. este accesibilă lumii exterioare. Dezactivați modul de depanare setând valoarea <code>APP_DEBUG</code> din fișierul <code>.env</code> la <code>false</code>.',
    'delete'  				=> 'Sterge',
    'delete_confirm'  		=> 'Are you sure you wish to delete :item?',
    'deleted'  				=> 'Sters',
    'delete_seats'  		=> 'Locurile șterse',
    'departments'           => 'departamente',
    'department'           => 'Departament',
    'deployed'				=> 'Pus in folosinta',
    'depreciation_report'	=> 'Raport depreciere',
    'details'               => 'Details',
    'download'				=> 'Descarca',
    'download_all'				=> 'Download All',
    'depreciation'			=> 'Depreciere',
    'editprofile'  			=> 'Editeaza propriul profil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Domeniul de e-mail',
    'email_format'			=> 'Formatul e-mailului',
    'email_domain_help'		=> 'Acesta este folosit pentru a genera adrese de e-mail atunci când importați',
    'filastname_format'			=> 'Primul nume inițial (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Nume Prenume Nume (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'First Name Last Name (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Last Name First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Primul',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Prenume',
    'first_name_format'		=> 'Prenume (jane@example.com)',
    'files'                 => 'Files',
    'file_name'				=> 'Fisier',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Upload fisier',
    'generate'				=> 'Genereaza',
     'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'Grupuri',
    'gravatar_email'        => 'Adresa E-mail Gravatar',
    'history'  			    => 'Istorie',
    'history_for'  			=> 'Istoric pentru',
    'id'  					=> 'ID',
    'image'                 => 'Image',
    'image_delete'         	=> 'Sterge poza',
    'image_upload'         	=> 'Incarca poza',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Import',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Istoricul importurilor',
    'asset_maintenance'        => 'Mentenanta produs',
    'asset_maintenance_report' => 'Raport privind mentenanta produsului',
    'asset_maintenances'       => 'Întreținerea activelor',
    'item'  				=> 'Articol',
    'insufficient_permissions' => 'Nu aveti permisiuni suficiente!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Limba',
    'last'					=> 'Ultimul',
    'last_login'            => 'Ultima logare',
    'last_name'             => 'Nume',
    'license'				=> 'Licenta',
    'license_report'        => 'Raport licente',
    'licenses_available'	=> 'Licente disponibile',
    'licenses'				=> 'Licente',
    'list_all'				=> 'Arata tot',
    'loading'				=> 'se incarca',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Această funcție a fost dezactivată pentru instalarea demonstrativă.',
    'location'              => 'Locatie',
    'locations'				=> 'Locatii',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Log out',
    'lookup_by_tag'     => 'Căutarea după eticheta de activ',
    'maintenances'          => 'Maintenances',
    'manufacturer'			=> 'Producator',
    'manufacturers'			=> 'Producatori',
    'markdown'				=> 'Acest câmp permite marcarea <a href="https://help.github.com/articles/github-flavored-markdown/">Github markdown</a>.',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'	=> 'Numărul minim de elemente care ar trebui să fie disponibile înainte de declanșarea unei alerte.',
    'model_no'				=> 'Nr. model',
    'months'				=> 'luni',
    'moreinfo'				=> 'Mai multe',
    'name'					=> 'Nume',
    'next'					=> 'Următor →',
    'next_audit_date'		=> 'Data următoarei auditări',
    'last_audit'		    => 'Ultimul audit',
    'new'					=> 'nou!',
    'no_depreciation'		=> 'Fara depreciere',
    'no_results'			=> 'Nici un rezultat.',
    'no'  					=> 'Nr',
    'notes'  				=> 'Note',
    'order_number'          => 'Numar de ordine',
    'page_menu'				=> 'Se afișează elementele _MENU_',
    'pagination_info'		=> 'Se afișează _START_ la _END_ din _TOTAL_ elemente',
    'pending'				=> 'In asteptare',
    'people'				=> 'Oameni',
    'per_page'				=> 'Rezultate pe pagina',
    'previous'				=> 'Anterior',
    'processing'			=> 'Prelucrare',
    'profile'				=> 'Profilul dvs.',
    'purchase_cost'                              => 'Costul de achiziție',
    'purchase_date'         => 'Data cumpărării',
    'qty'		            => 'QTY',
    'quantity'		        => 'Cantitate',
    'ready_to_deploy'		=> 'Gata de lansare',
    'recent_activity'		=> 'Activitate recentă',
    'remove_company'        => 'Eliminați asocierea companiilor',
    'reports'				=> 'Rapoarte',
    'restored'				=> 'restored',
    'requested'				=> 'Cereri',
    'request_canceled'      => 'Cerere anulată',
    'save'  				=> 'Salveaza',
    'select'				=> 'Selectați',
    'search'				=> 'Căutare',
    'select_category'       => 'Selectați o categorie',
    'select_department'       => 'Selectați un departament',
    'select_depreciation'	=> 'Selectați un tip de amortizare',
    'select_location'		=> 'Selectați o locație',
    'select_manufacturer'	=> 'Selectați un producător',
    'select_model'			=> 'Selectați un model',
    'select_supplier'		=> 'Selectați un furnizor',
    'select_user'			=> 'Selectati un utilizatori',
    'select_date'			=> 'Selectați data (AAAA-MM-DD)',
    'select_statuslabel'	=> 'Selecteaza Starea',
    'select_company'    	=> 'Selectați Companie',
    'select_asset'    		=> 'Selectați Activ',
    'settings'				=> 'Setari',
    'show_deleted'  		=> 'Show Deleted',
    'show_current'  		=> 'Show Current',
    'sign_in'				=> 'Logheaza-te',
    'signature'             => 'Semnătură',
    'skin'       			=> 'Skin',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'Modul DEMO: Unele caracteristici sunt dezactivate pentru această instalare.',
    'site_name'				=> 'Nume site',
    'state'  				=> 'Judet',
    'status_labels'			=> 'Etichete status',
    'status'    			=> 'Stare',
    'supplier'              => 'Furnizor',
    'suppliers'  			=> 'Furnizori',
    'sure_to_delete'    => 'Sigur doriți să ștergeți',
    'submit'				=> 'A depune',
    'target'                => 'Ţintă',
    'time_and_date_display' => 'Afișarea orei și a datei',
    'total_assets'			=> 'Total active',
    'total_licenses'		=> 'Total licente',
    'total_accessories'		=> 'accesorii complete',
    'total_consumables'		=> 'consumabile totale',
    'type'  				=> 'Tipul',
    'undeployable'			=> 'Nelansabil',
    'unknown_admin'			=> 'Admin necunoscut',
    'username_format'		=> 'Nume de utilizator Format',
    'update'                => 'Actualizează',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Încărcat',
    'user'					=> 'Utilizator',
    'accepted'			    => 'acceptat',
    'declined'			    => 'respins',
    'unaccepted_asset_report' => 'Produse neacceptate',
    'users'                 => 'Utilizatori',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Vezi active desemnate',
    'website'               => 'Website',
    'welcome'				=> 'Bine ati venit, :name',
    'years'					=> 'ani',
    'yes' 					=> 'Da',
    'zip'  					=> 'Cod postal',
    'noimage'				=> 'Nici o imagine incarcata sau imaginea nu exista.',
    'token_expired'         => 'Sesiunea de formular a expirat. Vă rugăm să încercați din nou.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ro/general.php <==
<?php

    return [
    'accessories'			=> 'Accesorii',
    'activated'			    => 'activat',
    'accessory'				=> 'Accesorii',
    'accessory_report'		=> 'Raportul accesoriu',
    'action'                => 'Acțiune',
    'activity_report'		=> 'Raport de activitate',
    'address'				=> 'Adresa',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Adăugat scaune',
    'all_assets'			=> 'Toate activele',
    'all'       			=> 'Toate',
    'archived'              => 'Arhivat',
    'asset_models'			=> 'Modele active',
    'asset_model'			=> 'Model',
    'asset'					=> 'Activ',
    'asset_report'          => 'Raport de active',
    'asset_tag'				=> 'Eticheta activ',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Assets available',
    'accept_assets'         => 'Accept Assets :name',
    'accept_assets_menu'    => 'Accept Assets',
    'audit'				    => 'Audit',
    'audit_report'			=> 'Jurnal de audit',
    'assets'				=> 'Active',
    'avatar_delete'         => 'Sterge avatar',
    'avatar_upload'         => 'Upload Avatar',
    'back'      			=> 'Inapoi',
    'bad_data'      		=> 'Nimic gasit. Poate date proaste?',
    'bulkaudit'             => 'Auditul în bloc',
    'bulkaudit_status'      => 'Starea auditului',
    'bulk_checkout'  		=> 'Comenzi în numerar',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Anuleaza',
    'categories'			=> 'Categorii',
    'category'				=> 'Categoria',
    'change' 		        => 'În afară',
    'changeemail'  			=> 'Schimba adresa de E-mail',
    'changepassword'  		=> 'Schimba parola',
    'checkin'  				=> 'Primeste',
    'checkin_from'  		=> 'Checkin de la',
    'checkout'  			=> 'Preda',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Requests',
    'city'  				=> 'Oras',
    'click_here'			=> 'Click aici',
    'clear_selection'		=> 'Clear Selection',
    'companies'			    => 'Companii',
    'company'				=> 'Companie',
    'component'			    => 'component',
    'components'			=> 'Componente',
    'complete'				=> 'Complet',
    'consumable'			=> 'Consumabil',
    'consumables'			=> 'Consumabile',
    'country'  				=> 'Tara',
    'create'				=> 'Creeaza',
    'created'               => 'Articol creat',
    'created_asset'			=> 'Activ creat',
    'created_at' 			=> 'Creat la',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Actualizat la',
    'currency'  			=> 'LEI', // this is deprecated
    'current'  				=> 'Curent',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Raport active custom',
    'dashboard'				=> 'Bord',
    'days'      			=> 'zi',
    'days_to_next_audit'    => 'Zile până la următorul audit',
    'date'					=> 'Data',
    'debug_warning'         => 'Avertizare!',
    'debug_warning_text'    => 'Această aplicație rulează în modul de producție cu debugging activat. Acest lucru poate expune date sensibile dacă aplicația dvs. este accesibilă lumii exterioare. Dezactivați modul de depanare setând valoarea <code>APP_DEBUG</code> din fișierul <code>.env</code> la <code>false</code>.',
    'delete'  				=> 'Sterge',
    'delete_confirm'  		=> 'Sigur doriți să ștergeți :item?',
    'deleted'  				=> 'Sters',
    'delete_seats'  		=> 'Locurile șterse',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'departamente',
    'department'            => 'Departament',
    'deployed'				=> 'Pus in folosinta',
    'depreciation'			=> 'Depreciere',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Raport depreciere',
    'details'               => 'Details',
    'download'				=> 'Descarca',
    'download_all'		    => 'Download All',
    'editprofile'  			=> 'Editeaza propriul profil',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Domeniul de e-mail',
    'email_format'			=> 'Formatul e-mailului',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'Acesta este folosit pentru a genera adrese de e-mail atunci când importați',
    'error'				    => 'Error',
    'filastname_format'			=> 'Primul nume inițial (jsmith@example.com)',
    'firstname_lastname_format'	=> 'Nume Prenume Nume (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'First Name Last Name (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Last Name First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Primul',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Prenume',
    'first_name_format'		=> 'Prenume (jane@example.com)',
    'files'                 => 'Files',
    'file_name'				=> 'Fisier',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Upload fisier',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Genereaza',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'Grupuri',
    'gravatar_email'        => 'Adresa E-mail Gravatar',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'Istorie',
    'history_for'  			=> 'Istoric pentru',
    'id'  					=> 'ID',
    'image'                 => 'Image',
    'image_delete'         	=> 'Sterge poza',
    'image_upload'         	=> 'Incarca poza',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Import',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Istoricul importurilor',
    'asset_maintenance'        => 'Mentenanta produs',
    'asset_maintenance_report' => 'Raport privind mentenanta produsului',
    'asset_maintenances'       => 'Întreținerea activelor',
    'item'  				=> 'Articol',
    'item_name'             => 'Item Name',
    'insufficient_permissions' => 'Nu aveti permisiuni suficiente!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Limba',
    'last'					=> 'Ultimul',
    'last_login'            => 'Ultima logare',
    'last_name'             => 'Nume',
    'license'				=> 'Licenta',
    'license_report'        => 'Raport licente',
    'licenses_available'	=> 'Licente disponibile',
    'licenses'				=> 'Licente',
    'list_all'				=> 'Arata tot',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Această funcție a fost dezactivată pentru instalarea demonstrativă.',
    'location'              => 'Locatie',
    'locations'				=> 'Locatii',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Log out',
    'lookup_by_tag'     => 'Căutarea după eticheta de activ',
    'maintenances'          => 'Maintenances',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Producator',
    'manufacturers'			=> 'Producatori',
    'markdown'				=> 'Acest câmp permite marcarea <a href="https://help.github.com/articles/github-flavored-markdown/">Github markdown</a>.',
    'min_amt'				=> 'Min. QTY',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'Nr. model',
    'months'				=> 'luni',
    'moreinfo'				=> 'Mai multe',
    'name'					=> 'Nume',
    'new_password'          => 'New Password',
    'next'					=> 'Următor →',
    'next_audit_date'		=> 'Data următoarei auditări',
    'last_audit'		    => 'Ultimul audit',
    'new'					=> 'nou!',
    'no_depreciation'		=> 'Fara depreciere',
    'no_results'			=> 'Nici un rezultat.',
    'no'  					=> 'Nr',
    'notes'  				=> 'Note',
    'order_number'          => 'Numar de ordine',
    'page_menu'				=> 'Se afișează elementele _MENU_',
    'pagination_info'		=> 'Se afișează _START_ la _END_ din _TOTAL_ elemente',
    'pending'				=> 'In asteptare',
    'people'				=> 'Oameni',
    'per_page'				=> 'Rezultate pe pagina',
    'previous'				=> 'Anterior',
    'processing'			=> 'Prelucrare',
    'profile'				=> 'Profilul dvs.',
    'purchase_cost'                              => 'Costul de achiziție',
    'purchase_date'         => 'Data cumpărării',
    'qty'		            => 'QTY',
    'quantity'		        => 'Cantitate',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Gata de lansare',
    'recent_activity'		=> 'Activitate recentă',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Eliminați asocierea companiilor',
    'reports'				=> 'Rapoarte',
    'restored'				=> 'restored',
    'restore'				=> 'Restore',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Cereri',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Cerere anulată',
    'save'  				=> 'Salveaza',
    'select'				=> 'Selectați',
    'select_all'            => 'Select All',
    'search'				=> 'Căutare',
    'select_category'       => 'Selectați o categorie',
    'select_department'     => 'Selectați un departament',
    'select_depreciation'	=> 'Selectați un tip de amortizare',
    'select_location'		=> 'Selectați o locație',
    'select_manufacturer'	=> 'Selectați un producător',
    'select_model'			=> 'Selectați un model',
    'select_supplier'		=> 'Selectați un furnizor',
    'select_user'			=> 'Selectati un utilizatori',
    'select_date'			=> 'Selectați data (AAAA-MM-DD)',
    'select_statuslabel'	=> 'Selecteaza Starea',
    'select_company'    	=> 'Selectați Companie',
    'select_asset'    		=> 'Selectați Activ',
    'settings'				=> 'Setari',
    'show_deleted'  		=> 'Show Deleted',
    'show_current'  		=> 'Show Current',
    'sign_in'				=> 'Logheaza-te',
    'signature'             => 'Semnătură',
    'skin'       			=> 'Skin',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'Modul DEMO: Unele caracteristici sunt dezactivate pentru această instalare.',
    'site_name'				=> 'Nume site',
    'state'  				=> 'Judet',
    'status_labels'			=> 'Etichete status',
    'status'    			=> 'Stare',
    'supplier'              => 'Furnizor',
    'suppliers'  			=> 'Furnizori',
    'sure_to_delete'    => 'Sigur doriți să ștergeți',
    'submit'				=> 'A depune',
    'target'                => 'Ţintă',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Afișarea orei și a datei',
    'total_assets'			=> 'Total active',
    'total_licenses'		=> 'Total licente',
    'total_accessories'		=> 'accesorii complete',
    'total_consumables'		=> 'consumabile totale',
    'type'  				=> 'Tipul',
    'undeployable'			=> 'Nelansabil',
    'unknown_admin'			=> 'Admin necunoscut',
    'username_format'		=> 'Nume de utilizator Format',
    'update'                => 'Actualizează',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Încărcat',
    'user'					=> 'Utilizator',
    'accepted'			    => 'acceptat',
    'declined'			    => 'respins',
    'unaccepted_asset_report' => 'Produse neacceptate',
    'users'                 => 'Utilizatori',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Vezi active desemnate',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Website',
    'welcome'				=> 'Bine ati venit, :name',
    'years'					=> 'ani',
    'yes' 					=> 'Da',
    'zip'  					=> 'Cod postal',
    'noimage'				=> 'Nici o imagine incarcata sau imaginea nu exista.',
    'token_expired'         => 'Sesiunea de formular a expirat. Vă rugăm să încercați din nou.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
